@@ -12,13 +12,13 @@ oldopen = open
 
 
 def if_changed(targets):
-    subprocess.call(['gdo','--if','Changed']+targets)
+    code = subprocess.call(['gdo','--if','Changed']+targets)
     if code != 0:
         exit(1)
 
 
 def if_created(targets):
-    subprocess.call(['gdo','--if','Created']+targets)
+    code = subprocess.call(['gdo','--if','Created']+targets)
     if code != 0:
         exit(1)
 
